CastSet

Struct CastSet 

pub struct CastSet<T: Cast> { /* private fields */ }
A set implemented for types that can be cast to usize

Implementations

Source

impl<T: Cast> CastSet<T>

pub fn new() -> CastSet<T>

Creates an empty set..

pub fn with_capacity(cap: usize) -> CastSet<T>

Creates an empty set with the specified capacity.

pub fn len(&self) -> usize

Returns the number of elements in the set.

pub fn reserve(&mut self, additional: usize)

Reserves capacity for at least additional more elements to be inserted in the set. The collection may reserve more space to avoid frequent reallocations.

pub fn insert(&mut self, elem: T) -> bool

Adds a value to the set.

If the set did not have this value present, true is returned.

If the set did have this value present, false is returned.

pub fn contains(&self, value: &T) -> bool

Returns true if the set contains a value.

pub fn remove(&mut self, value: &T) -> bool

Removes an element, and returns true if that element was present.

pub fn iter(&self) -> Iter<'_, T>

Returns an iterator over the set.

pub fn drain(&mut self) -> IntoIter<T>

Clears the set, returning all elements in an iterator.