VecSet

Struct VecSet 

pub struct VecSet<T> { /* private fields */ }
A set that is stored in a Vec

Implementations

Source

impl<T: Eq> VecSet<T>

pub fn new() -> VecSet<T>

Creates an empty set..

pub fn len(&self) -> usize

Returns the number of elements in the set.

pub fn insert(&mut self, elem: T) -> bool

Adds a value to the set.

If the set did not have this value present, true is returned.

If the set did have this value present, false is returned.

pub fn contains<Q>(&self, value: &Q) -> bool
where T: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns true if the set contains a value.

pub fn remove<Q>(&mut self, value: &Q) -> bool
where T: Borrow<Q>, Q: Hash + Eq + ?Sized,

Removes an element, and returns true if that element was present.

pub fn iter(&self) -> Iter<'_, T>

Returns an iterator over the set.