pub struct CastSet<T: Cast> { /* private fields */ }Expand description
A set implemented for types that can be cast to usize
Implementations
Sourceimpl<T: Cast> CastSet<T>
impl<T: Cast> CastSet<T>
Sourcepub fn with_capacity(cap: usize) -> CastSet<T>
pub fn with_capacity(cap: usize) -> CastSet<T>
Creates an empty set with the specified capacity.
Sourcepub fn reserve(&mut self, additional: usize)
pub fn reserve(&mut self, additional: usize)
Reserves capacity for at least additional more elements to be
inserted in the set. The collection may reserve more space
to avoid frequent reallocations.
Sourcepub fn insert(&mut self, elem: T) -> bool
pub fn insert(&mut self, elem: T) -> bool
Adds a value to the set.
If the set did not have this value present, true is returned.
If the set did have this value present, false is returned.