pub struct VecSet<T> { /* private fields */ }Expand description
A set that is stored in a Vec
Implementations
Sourceimpl<T: Eq> VecSet<T>
impl<T: Eq> VecSet<T>
Sourcepub fn insert(&mut self, elem: T) -> bool
pub fn insert(&mut self, elem: T) -> bool
Adds a value to the set.
If the set did not have this value present, true is returned.
If the set did have this value present, false is returned.